@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 #!python3
-
-
 import os
 import sys
+"major=2, minor=7, micro=17"
+python_version=str(sys.version_info.major)+"."+str(sys.version_info.minor)
+unix="~/Library/Python/%s/bin" % python_version
 a = sys.platform
 def install():
     exitcode=os.system('python3 -m pip install pyinstaller')
